TaggedPointer

Struct TaggedPointer 

#[repr(transparent)]
pub struct TaggedPointer<T: ?Sized> { pub raw: *mut T, }
Structure wrapping a raw, tagged pointer.

Fields

raw: *mut T

Implementations

Source

impl<T> TaggedPointer<T>

pub fn new(raw: *mut T) -> TaggedPointer<T>

Returns a new TaggedPointer without setting any bits.

pub fn with_bit(raw: *mut T, bit: usize) -> TaggedPointer<T>

Returns a new TaggedPointer with the given bit set.

pub fn unset_bit(&mut self, bit: usize)

pub const fn null() -> TaggedPointer<T>

Returns a null pointer.

pub fn untagged(self) -> *mut T

Returns the wrapped pointer without any tags.

pub fn without_tags(self) -> Self

Returns a new TaggedPointer using the current pointer but without any tags.

pub fn bit_is_set(self, bit: usize) -> bool

Returns true if the given bit is set.

pub fn set_bit(&mut self, bit: usize)

Sets the given bit.

pub fn is_null(self) -> bool

Returns true if the current pointer is a null pointer.

pub fn as_ref<'a>(self) -> Option<&'a T>

Returns an immutable to the pointer’s value.

pub fn as_mut<'a>(self) -> Option<&'a mut T>

Returns a mutable reference to the pointer’s value.

pub fn compare_and_swap(&self, current: *mut T, other: *mut T) -> bool

Atomically swaps the internal pointer with another one.

This boolean returns true if the pointer was swapped, false otherwise.

pub fn atomic_store(&self, other: *mut T)

Atomically replaces the current pointer with the given one.

pub fn atomic_load(&self) -> *mut T

Atomically loads the pointer.

pub fn atomic_bit_is_set(&self, bit: usize) -> bool

Checks if a bit is set using an atomic load.