#[repr(transparent)]pub struct TaggedPointer<T: ?Sized> {
pub raw: *mut T,
}Expand description
Structure wrapping a raw, tagged pointer.
Fields
raw: *mut TImplementations
Sourceimpl<T> TaggedPointer<T>
impl<T> TaggedPointer<T>
Sourcepub fn new(raw: *mut T) -> TaggedPointer<T>
pub fn new(raw: *mut T) -> TaggedPointer<T>
Returns a new TaggedPointer without setting any bits.
Sourcepub fn with_bit(raw: *mut T, bit: usize) -> TaggedPointer<T>
pub fn with_bit(raw: *mut T, bit: usize) -> TaggedPointer<T>
Returns a new TaggedPointer with the given bit set.
pub fn unset_bit(&mut self, bit: usize)
Sourcepub const fn null() -> TaggedPointer<T>
pub const fn null() -> TaggedPointer<T>
Returns a null pointer.
Returns a new TaggedPointer using the current pointer but without any tags.
Sourcepub fn bit_is_set(self, bit: usize) -> bool
pub fn bit_is_set(self, bit: usize) -> bool
Returns true if the given bit is set.
Sourcepub fn as_mut<'a>(self) -> Option<&'a mut T>
pub fn as_mut<'a>(self) -> Option<&'a mut T>
Returns a mutable reference to the pointer’s value.
Sourcepub fn compare_and_swap(&self, current: *mut T, other: *mut T) -> bool
pub fn compare_and_swap(&self, current: *mut T, other: *mut T) -> bool
Atomically swaps the internal pointer with another one.
This boolean returns true if the pointer was swapped, false otherwise.
Sourcepub fn atomic_store(&self, other: *mut T)
pub fn atomic_store(&self, other: *mut T)
Atomically replaces the current pointer with the given one.
Sourcepub fn atomic_load(&self) -> *mut T
pub fn atomic_load(&self) -> *mut T
Atomically loads the pointer.
Sourcepub fn atomic_bit_is_set(&self, bit: usize) -> bool
pub fn atomic_bit_is_set(&self, bit: usize) -> bool
Checks if a bit is set using an atomic load.